import common_pb2 as _common_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SendTaskRequest(_message.Message):
    __slots__ = ["input_files", "task"]
    INPUT_FILES_FIELD_NUMBER: _ClassVar[int]
    TASK_FIELD_NUMBER: _ClassVar[int]
    input_files: _containers.RepeatedScalarFieldContainer[str]
    task: str
    def __init__(self, input_files: _Optional[_Iterable[str]] = ..., task: _Optional[str] = ...) -> None: ...

class OnAgentAction(_message.Message):
    __slots__ = ["input", "tool"]
    INPUT_FIELD_NUMBER: _ClassVar[int]
    TOOL_FIELD_NUMBER: _ClassVar[int]
    input: str
    tool: str
    def __init__(self, input: _Optional[str] = ..., tool: _Optional[str] = ...) -> None: ...

class OnAgentActionEnd(_message.Message):
    __slots__ = ["output", "output_files"]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FILES_FIELD_NUMBER: _ClassVar[int]
    output: str
    output_files: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, output: _Optional[str] = ..., output_files: _Optional[_Iterable[str]] = ...) -> None: ...

class FinalRespond(_message.Message):
    __slots__ = ["answer"]
    ANSWER_FIELD_NUMBER: _ClassVar[int]
    answer: str
    def __init__(self, answer: _Optional[str] = ...) -> None: ...

class TaskRespond(_message.Message):
    __slots__ = ["token_usage", "iteration", "model_name", "on_agent_action", "on_agent_action_end", "final_respond"]
    TOKEN_USAGE_FIELD_NUMBER: _ClassVar[int]
    ITERATION_FIELD_NUMBER: _ClassVar[int]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    ON_AGENT_ACTION_FIELD_NUMBER: _ClassVar[int]
    ON_AGENT_ACTION_END_FIELD_NUMBER: _ClassVar[int]
    FINAL_RESPOND_FIELD_NUMBER: _ClassVar[int]
    token_usage: int
    iteration: int
    model_name: str
    on_agent_action: OnAgentAction
    on_agent_action_end: OnAgentActionEnd
    final_respond: FinalRespond
    def __init__(self, token_usage: _Optional[int] = ..., iteration: _Optional[int] = ..., model_name: _Optional[str] = ..., on_agent_action: _Optional[_Union[OnAgentAction, _Mapping]] = ..., on_agent_action_end: _Optional[_Union[OnAgentActionEnd, _Mapping]] = ..., final_respond: _Optional[_Union[FinalRespond, _Mapping]] = ...) -> None: ...

class AddKernelRequest(_message.Message):
    __slots__ = ["endpoint", "key"]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    endpoint: str
    key: str
    def __init__(self, endpoint: _Optional[str] = ..., key: _Optional[str] = ...) -> None: ...

class AddKernelResponse(_message.Message):
    __slots__ = ["code", "msg"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    code: int
    msg: str
    def __init__(self, code: _Optional[int] = ..., msg: _Optional[str] = ...) -> None: ...



import common_pb2 as _common_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class StartKernelRequest(_message.Message):
    __slots__ = ["kernel_name"]
    KERNEL_NAME_FIELD_NUMBER: _ClassVar[int]
    kernel_name: str
    def __init__(self, kernel_name: _Optional[str] = ...) -> None: ...

class StartKernelResponse(_message.Message):
    __slots__ = ["code", "msg"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    code: int
    msg: str
    def __init__(self, code: _Optional[int] = ..., msg: _Optional[str] = ...) -> None: ...

class StopKernelRequest(_message.Message):
    __slots__ = ["kernel_name"]
    KERNEL_NAME_FIELD_NUMBER: _ClassVar[int]
    kernel_name: str
    def __init__(self, kernel_name: _Optional[str] = ...) -> None: ...

class StopKernelResponse(_message.Message):
    __slots__ = ["code", "msg"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    code: int
    msg: str
    def __init__(self, code: _Optional[int] = ..., msg: _Optional[str] = ...) -> None: ...

class RestartKernelRequest(_message.Message):
    __slots__ = ["kernel_name"]
    KERNEL_NAME_FIELD_NUMBER: _ClassVar[int]
    kernel_name: str
    def __init__(self, kernel_name: _Optional[str] = ...) -> None: ...

class RestartKernelResponse(_message.Message):
    __slots__ = ["code", "msg"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    code: int
    msg: str
    def __init__(self, code: _Optional[int] = ..., msg: _Optional[str] = ...) -> None: ...

class ExecuteRequest(_message.Message):
    __slots__ = ["code", "kernel_name"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    KERNEL_NAME_FIELD_NUMBER: _ClassVar[int]
    code: str
    kernel_name: str
    def __init__(self, code: _Optional[str] = ..., kernel_name: _Optional[str] = ...) -> None: ...

class ExecuteResponse(_message.Message):
    __slots__ = ["result", "stdout", "stderr", "traceback"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    STDOUT_FIELD_NUMBER: _ClassVar[int]
    STDERR_FIELD_NUMBER: _ClassVar[int]
    TRACEBACK_FIELD_NUMBER: _ClassVar[int]
    result: str
    stdout: str
    stderr: str
    traceback: str
    def __init__(self, result: _Optional[str] = ..., stdout: _Optional[str] = ..., stderr: _Optional[str] = ..., traceback: _Optional[str] = ...) -> None: ...

class GetStatusRequest(_message.Message):
    __slots__ = ["kernel_name"]
    KERNEL_NAME_FIELD_NUMBER: _ClassVar[int]
    kernel_name: str
    def __init__(self, kernel_name: _Optional[str] = ...) -> None: ...

class GetStatusResponse(_message.Message):
    __slots__ = ["is_alive", "code", "msg"]
    IS_ALIVE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    MSG_FIELD_NUMBER: _ClassVar[int]
    is_alive: bool
    code: int
    msg: str
    def __init__(self, is_alive: bool = ..., code: _Optional[int] = ..., msg: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent_server.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61gent_server.proto\x12\x13octopus_agent_proto\x1a\x0c\x63ommon.proto\"4\n\x0fSendTaskRequest\x12\x13\n\x0binput_files\x18\x01 \x03(\t\x12\x0c\n\x04task\x18\x02 \x01(\t\",\n\rOnAgentAction\x12\r\n\x05input\x18\x01 \x01(\t\x12\x0c\n\x04tool\x18\x02 \x01(\t\"8\n\x10OnAgentActionEnd\x12\x0e\n\x06output\x18\x01 \x01(\t\x12\x14\n\x0coutput_files\x18\x02 \x03(\t\"\x1e\n\x0c\x46inalRespond\x12\x0e\n\x06\x61nswer\x18\x01 \x01(\t\"\x92\x02\n\x0bTaskRespond\x12\x13\n\x0btoken_usage\x18\x01 \x01(\x05\x12\x11\n\titeration\x18\x02 \x01(\x05\x12\x12\n\nmodel_name\x18\x03 \x01(\t\x12=\n\x0fon_agent_action\x18\x05 \x01(\x0b\x32\".octopus_agent_proto.OnAgentActionH\x00\x12\x44\n\x13on_agent_action_end\x18\x06 \x01(\x0b\x32%.octopus_agent_proto.OnAgentActionEndH\x00\x12:\n\rfinal_respond\x18\x07 \x01(\x0b\x32!.octopus_agent_proto.FinalRespondH\x00\x42\x06\n\x04\x62ody\"1\n\x10\x41\x64\x64KernelRequest\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\".\n\x11\x41\x64\x64KernelResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t2\xf0\x02\n\x0b\x41gentServer\x12Q\n\x06upload\x12\x1f.octopus_common_proto.FileChunk\x1a\".octopus_common_proto.FileUploaded\"\x00(\x01\x12V\n\x08\x64ownload\x12%.octopus_common_proto.DownloadRequest\x1a\x1f.octopus_common_proto.FileChunk\"\x00\x30\x01\x12W\n\tsend_task\x12$.octopus_agent_proto.SendTaskRequest\x1a .octopus_agent_proto.TaskRespond\"\x00\x30\x01\x12]\n\nadd_kernel\x12%.octopus_agent_proto.AddKernelRequest\x1a&.octopus_agent_proto.AddKernelResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent_server_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SENDTASKREQUEST']._serialized_start=57
  _globals['_SENDTASKREQUEST']._serialized_end=109
  _globals['_ONAGENTACTION']._serialized_start=111
  _globals['_ONAGENTACTION']._serialized_end=155
  _globals['_ONAGENTACTIONEND']._serialized_start=157
  _globals['_ONAGENTACTIONEND']._serialized_end=213
  _globals['_FINALRESPOND']._serialized_start=215
  _globals['_FINALRESPOND']._serialized_end=245
  _globals['_TASKRESPOND']._serialized_start=248
  _globals['_TASKRESPOND']._serialized_end=522
  _globals['_ADDKERNELREQUEST']._serialized_start=524
  _globals['_ADDKERNELREQUEST']._serialized_end=573
  _globals['_ADDKERNELRESPONSE']._serialized_start=575
  _globals['_ADDKERNELRESPONSE']._serialized_end=621
  _globals['_AGENTSERVER']._serialized_start=624
  _globals['_AGENTSERVER']._serialized_end=992
# @@protoc_insertion_point(module_scope)
